// 系统专项设置api文件
import request from '@/utils/request'
import qs from 'qs'
let api = '/api-web'
// 分页查询分部列表
export function branchQueryPage(data) {
    return request({
        url: api + '/organization/queryPage',
        method: 'get',
        params: data
    })
}

// 分页查询分部列表
export function branchAdd(data) {
    return request({
        url: api + '/organization/add',
        method: 'post',
        data: qs.stringify(data)
    })
}

// 分页查询分部列表
export function branchUpdate(data) {
    return request({
        url: api + '/organization/update',
        method: 'post',
        data: qs.stringify(data)
    })
}

// 根据父节点查询下一级子节点列表（不递归）
export function areaQueryChild(data) {
    return request({
        url: api + '/area/queryChild',
        method: 'get',
        params: data
    })
}


// 根据子级区域获取父级节点
export function getParentArea(data) {
    return request({
        url: api + `/area/getParentArea/${data.id}`,
        method: 'get'
    })
}

// 分页查询科目列表
export function subjectListTree(data) {
    return request({
        url: api + `/subject/queryPageTree`,
        method: 'get',
        params: data
    })
}

// 修改、新增科目
export function subjectUpset(data) {
    return request({
        url: api + `/subject/upset`,
        method: 'post',
        data: data
    })
}

// 分页查询收费类型列表
export function chargeTypeList(data) {
    return request({
        url: api + '/chargeType/queryPage',
        method: 'get',
        params: data
    })
}

// 新增、修改收费类型
export function chargeTypeUpSet(data) {
    return request({
        url: api + '/chargeType/upSet',
        method: 'post',
        data: data
    })
}

// 删除收费类型
export function chargeTypeDel(data) {
    return request({
        url: api + `/chargeType/del/${data}`,
        method: 'post'
    })
}

// 分页查询作业模板列表
export function courseHomeworkTemplateList(data) {
    return request({
        url: api + '/courseHomeworkTemplate/queryPage',
        method: 'post',
        data: data
    })
}

// 修改作业模板
export function homeWorkUpdate(data) {
    return request({
        url: api + '/courseHomeworkTemplate/update',
        method: 'post',
        data: qs.stringify(data)
    })
}

// 修改作业模板
export function homeWorkAdd(data) {
    return request({
        url: api + '/courseHomeworkTemplate/add',
        method: 'post',
        data: qs.stringify(data)
    })
}


// 修改作业模板
export function homeWorkDel(id) {
    return request({
        url: api + `/courseHomeworkTemplate/del/${id}`,
        method: 'post'
    })
}

// 查询已设置的分部列表
export function queryOrganIdList(data) {
    return request({
        url: api + `/courseScheduleRewards/queryOrganIdList`,
        method: 'get',
        params: data
    })
}

// 获取收费类型分部关联的默认课程费用添加
export function chargeTypeOrganizationFeeAdd(data) {
    return request({
        url: api + `/chargeTypeOrganizationFee/add`,
        method: 'post',
        data: qs.stringify(data)
    })
}

// 获取收费类型分部关联的默认课程费用删除
export function chargeTypeOrganizationFeeDelete(data) {
    return request({
        url: api + `/chargeTypeOrganizationFee/delete`,
        method: 'post',
        data: qs.stringify(data)
    })
}

// 获取收费类型分部关联的默认课程费用修改
export function chargeTypeOrganizationFeeUpdate(data) {
    return request({
        url: api + `/chargeTypeOrganizationFee/update`,
        method: 'post',
        data: qs.stringify(data)
    })
}

// 获取收费类型分部关联的默认课程费用列表
export function chargeTypeOrganizationFee(data) {
    return request({
        url: api + `/chargeTypeOrganizationFee/queryPage`,
        method: 'get',
        params: data
    })
}
